@@ -7,7 +7,7 @@ require Exporter;
 require DynaLoader;
 
 @ISA = qw(Exporter DynaLoader);
-$VERSION = "1.06";
+$VERSION = "1.07";
 
 bootstrap Locked::Storage $VERSION;
 
@@ -87,9 +87,13 @@ Will return a hexdump of the memory allocated.
 
 =back
 
-=head1 WARNING
+=head1 WARNINGS
 
-unlockall() known nothing of other mlock() calls except those in
+Users on systems may have restrictions on the amount of memory
+that may be locked.  This may cause lockall() to fail with 
+C<ENOMEM> which is not caught and will cause a fatal error.
+
+unlockall() knows nothing of other mlock() calls except those in
 its own constructor, so if you have multiple instances and you
 call unlockall() it will unlock the regions in those instances
 and they will not be relocked.  It is recommended that you either
@@ -106,7 +110,12 @@ the sensitive data in memory.
 
 Various failures in the C libraries are not checked.  Particularly
 C<ENOMEM> where there isn't enough system memory to allow the
-process or pages to be locked to RAM.
+process or pages to be locked to RAM.  This is particularly noted
+on systems such as linux and freebsd which restrict users (non root)
+to disallowing the calls either totally or based on the memory
+required to complete the lock (Thanks to Slaven Rezic for noting
+that a user can only lock 64kB by defaul on debian/jessie machines
+by default.)
 
 =head1 AUTHOR
 
